package com.ynet.life.format;

import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import java.io.File;
import java.text.DecimalFormat;
import java.text.ParseException;
import java.text.ParsePosition;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.dom4j.Document;
import org.dom4j.DocumentException;
import org.dom4j.Element;
import org.dom4j.io.SAXReader;

/* loaded from: com_ynet_life_format.jar:com/ynet/life/format/DownloadLifeFormat.class */
public class DownloadLifeFormat {
    public static final String DEFAULT_TIME_FORMAT_DB = "yyyyMMddHHmmss";
    public static final String DEFAULT_TIME_FORMAT_EN = "yyyy-MM-dd HH:mm:ss";
    public static final String DEFAULT_TIME_FORMAT_CN = "yyyy年MM月dd日 HH:mm:ss";
    public static final String DEFAULT_DATE_FORMAT_EN = "yyyy-MM-dd";
    public static final String DEFAULT_DATE_FORMAT_CN = "yyyy年MM月dd日";
    protected static final char[] CHINESE_MONEY_CONVERT_GROUP_IN = {25342, 20336, 20191};
    protected static final char[] CHINESE_MONEY_CONVERT_GROUP_OUT = {19975, 20159, 20806};
    protected static final char[] CHINESE_MONEY_CONVERT_DIGIT = {38646, 22777, 36144, 21441, 32902, 20237, 38470, 26578, 25420, 29590};
    protected static final String[] CHINESE_MONEY_UNIT = {"整", "分", "角", "圆"};

    private DownloadLifeFormat() {
    }

    public static String formatChineseCurrency(String money) {
        String money2;
        try {
            int dotPostion = money.indexOf(46);
            int decimalPart = 0;
            if (dotPostion >= 0) {
                if (Integer.parseInt(money.substring(dotPostion + 1)) > 0 && dotPostion >= 0) {
                    decimalPart = Integer.parseInt(money.substring(dotPostion + 1));
                    money2 = money.substring(0, dotPostion);
                } else {
                    money2 = money.substring(0, dotPostion);
                }
            } else {
                money2 = money;
            }
            StringBuffer prefix = new StringBuffer();
            StringBuffer suffix = new StringBuffer();
            if (decimalPart == 0) {
                suffix.append(CHINESE_MONEY_UNIT[0]);
            } else if (decimalPart < 10) {
                suffix.append(CHINESE_MONEY_CONVERT_DIGIT[decimalPart]);
                suffix.append(CHINESE_MONEY_UNIT[1]);
            } else if (decimalPart % 10 == 0) {
                suffix.append(CHINESE_MONEY_CONVERT_DIGIT[decimalPart / 10]);
                suffix.append(CHINESE_MONEY_UNIT[2]);
            } else {
                suffix.append(CHINESE_MONEY_CONVERT_DIGIT[decimalPart / 10]);
                suffix.append(CHINESE_MONEY_UNIT[2]);
                suffix.append(CHINESE_MONEY_CONVERT_DIGIT[decimalPart % 10]);
                suffix.append(CHINESE_MONEY_UNIT[1]);
            }
            char[] chDig = money2.toCharArray();
            boolean zero = false;
            byte zeroSerNum = 0;
            for (int i = 0; i < chDig.length; i++) {
                int idx = ((chDig.length - i) - 1) % 4;
                int vidx = ((chDig.length - i) - 1) / 4;
                if (chDig[i] == '0') {
                    zeroSerNum = (byte) (zeroSerNum + 1);
                    if (!zero) {
                        zero = true;
                        if (idx == 0 && vidx > 0) {
                            prefix.append(CHINESE_MONEY_CONVERT_GROUP_OUT[vidx - 1]);
                        }
                    } else if (idx == 0 && vidx > 0 && zeroSerNum < 4) {
                        prefix.append(CHINESE_MONEY_CONVERT_GROUP_OUT[vidx - 1]);
                        zero = false;
                    }
                } else {
                    zeroSerNum = 0;
                    if (zero) {
                        prefix.append(CHINESE_MONEY_CONVERT_DIGIT[0]);
                        zero = false;
                    }
                    prefix.append(CHINESE_MONEY_CONVERT_DIGIT[chDig[i] - '0']);
                    if (idx > 0) {
                        prefix.append(CHINESE_MONEY_CONVERT_GROUP_IN[idx - 1]);
                    }
                    if (idx == 0 && vidx > 0) {
                        prefix.append(CHINESE_MONEY_CONVERT_GROUP_OUT[vidx - 1]);
                    }
                }
            }
            if (prefix.length() > 0) {
                prefix.append(CHINESE_MONEY_UNIT[3]);
            }
            return prefix.append(suffix).toString();
        } catch (Exception unused) {
            return "input error";
        }
    }

    public static String unFormatCurrency(String currency) {
        return currency.replaceAll("\\,", "");
    }

    public static String downLoadFormatCurrency(String currency) {
        if (currency == null) {
            return "";
        }
        try {
            double dCurr = Double.parseDouble(currency);
            return new DecimalFormat("#,##0.00").format(dCurr);
        } catch (Exception unused) {
            return currency;
        }
    }

    public static String formatCurrency(String currency) {
        if (currency == null) {
            return "";
        }
        try {
            Matcher m = Pattern.compile("\\d+\\.\\d{2}").matcher(currency);
            StringBuffer sb = new StringBuffer();
            while (m.find()) {
                double dCurr = Double.parseDouble(m.group(0));
                String replacement = new DecimalFormat("#,##0.00").format(dCurr);
                m.appendReplacement(sb, replacement);
            }
            m.appendTail(sb);
            return sb.toString();
        } catch (Exception unused) {
            return currency;
        }
    }

    public static String formatCurrency(String currency, boolean outputDot) {
        if (currency == null) {
            return "";
        }
        try {
            double dCurr = Double.parseDouble(currency);
            DecimalFormat dFmt = new DecimalFormat("#,##0.00");
            if (Boolean.valueOf(LifeStandard.getSelfDefineSettingsValue("amountSavedWithDot")).booleanValue() || !outputDot) {
                return dFmt.format(dCurr);
            }
            return dFmt.format(dCurr / 100.0d);
        } catch (Exception unused) {
            return currency;
        }
    }

    public static String appendZero(String currency) {
        if (currency == null) {
            return "";
        }
        try {
            Matcher m = Pattern.compile("\\d+\\.?\\d{0,2}").matcher(currency);
            StringBuffer sb = new StringBuffer();
            while (m.find()) {
                double dCurr = Double.parseDouble(m.group(0));
                String replacement = new DecimalFormat("#0.00").format(dCurr);
                m.appendReplacement(sb, replacement);
            }
            m.appendTail(sb);
            return sb.toString();
        } catch (Exception unused) {
            return currency;
        }
    }

    public static String formatDate(String date, String format) {
        SimpleDateFormat inFmt;
        SimpleDateFormat outFmt;
        ParsePosition pos = new ParsePosition(0);
        if (date == null || "".equals(date.trim())) {
            return "";
        }
        try {
            if (Long.parseLong(date) == 0) {
                return "";
            }
            try {
                switch (date.trim().length()) {
                    case 6:
                        inFmt = new SimpleDateFormat("yyyyMM");
                        break;
                    case 7:
                    case 9:
                    case 11:
                    case 13:
                    default:
                        return date;
                    case 8:
                        inFmt = new SimpleDateFormat("yyyyMMdd");
                        break;
                    case 10:
                        inFmt = new SimpleDateFormat("yyyyMMddHH");
                        break;
                    case 12:
                        inFmt = new SimpleDateFormat("yyyyMMddHHmm");
                        break;
                    case 14:
                        inFmt = new SimpleDateFormat("yyyyMMddHHmmss");
                        break;
                }
                Date dt = inFmt.parse(date, pos);
                if (dt == null) {
                    return date;
                }
                if (format == null || "".equals(format.trim())) {
                    outFmt = new SimpleDateFormat("yyyy年MM月dd日");
                } else {
                    outFmt = new SimpleDateFormat(format);
                }
                return outFmt.format(dt);
            } catch (Exception unused) {
                return date;
            }
        } catch (Exception unused2) {
            return date;
        }
    }

    public static String convertTimeFormat(String datetime, String oldFormat, String newFormat) {
        SimpleDateFormat oldFmt = new SimpleDateFormat(oldFormat);
        SimpleDateFormat newFmt = new SimpleDateFormat(newFormat);
        try {
            Date date = oldFmt.parse(datetime);
            return newFmt.format(date);
        } catch (ParseException ex) {
            Trace.logError("LifeCore", ex.getMessage(), ex);
            return datetime;
        }
    }

    public static String getDifferentTime(int hour, int minute, int second, String timeFormat) {
        String format = timeFormat == null ? "yyyyMMddHHmmss" : timeFormat;
        GregorianCalendar calendar = (GregorianCalendar) Calendar.getInstance();
        calendar.add(10, hour);
        calendar.add(12, minute);
        calendar.add(13, second);
        return new SimpleDateFormat(format).format(calendar.getTime());
    }

    public static String getDifferentDate(int days, String timeFormat) {
        return getDifferentTime(days * 24, 0, 0, timeFormat);
    }

    public static int dateCompare(String date1Str, String date2Str, String format) {
        ParsePosition pos = new ParsePosition(0);
        SimpleDateFormat simpleDateFormat = format == null ? new SimpleDateFormat("yyyyMMddHHmmss") : new SimpleDateFormat(format);
        SimpleDateFormat fmt = simpleDateFormat;
        Date dt1 = simpleDateFormat.parse(date1Str, pos);
        ParsePosition pos2 = new ParsePosition(0);
        Date dt2 = fmt.parse(date2Str, pos2);
        return dt1.compareTo(dt2);
    }

    public static String getSummary(String content, int summaryLength) {
        if (content == null || summaryLength <= 0) {
            return "";
        }
        if (content.length() > summaryLength) {
            return content.substring(0, summaryLength);
        }
        return content;
    }

    public static String nvl(Object dataValue, String returnValue) {
        if (dataValue == null || dataValue.toString().length() == 0) {
            return returnValue;
        }
        return dataValue.toString();
    }

    public static String getMessageByAppcode(String appCode, String fieldValue) {
        List list = new ArrayList();
        SAXReader reader = new SAXReader();
        String url = String.valueOf(LifeStandard.getRootPath()) + "WEB-INF/properties/parameters.xml";
        System.out.println("配置文件路径：".concat(String.valueOf(url)));
        Document document = null;
        Document document2 = null;
        try {
            document = reader.read(new File(url));
            document2 = document;
        } catch (DocumentException e) {
            document.printStackTrace();
        }
        Element rootElm = document2.getRootElement();
        rootElm.element("List");
        for (Element elm : rootElm.elements("List")) {
            if (elm.attributeValue("id").endsWith(appCode)) {
                for (Element elm2 : elm.elements("map")) {
                    HashMap hashMap = new HashMap();
                    System.out.println("key:" + elm2.attributeValue("key") + " value:" + elm2.attributeValue("value"));
                    hashMap.put("key", elm2.attributeValue("key"));
                    hashMap.put("value", elm2.attributeValue("value"));
                    list.add(hashMap);
                }
            }
        }
        Trace.logInfo("查询返回的集合列表：", list.toString());
        for (int a = 0; a < list.size(); a++) {
            Map map = (Map) list.get(a);
            if (map.get("key").equals(fieldValue)) {
                return map.get("value").toString();
            }
        }
        return fieldValue;
    }
}
